==> ec2-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/ISubnet.java <==
package software.amazon.awscdk.services.ec2;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:23:14.068Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ISubnet extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.core.IResource {

    /**
     * The Availability Zone the subnet is located in.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getAvailabilityZone();

    /**
     * Dependable that can be depended upon to force internet connectivity established on the VPC.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.core.IDependable getInternetConnectivityEstablished();

    /**
     * The route table for this subnet.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.ec2.IRouteTable getRouteTable();

    /**
     * The subnetId for this particular subnet.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getSubnetId();

    /**
     * Associate a Network ACL with this subnet.
     * 
     * @param id This parameter is required.
     * @param acl The Network ACL to associate. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    void associateNetworkAcl(final java.lang.String id, final software.amazon.awscdk.services.ec2.INetworkAcl acl);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.ISubnet {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
        }

        /**
         * The Availability Zone the subnet is located in.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getAvailabilityZone() {
            return this.jsiiGet("availabilityZone", java.lang.String.class);
        }

        /**
         * Dependable that can be depended upon to force internet connectivity established on the VPC.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.IDependable getInternetConnectivityEstablished() {
            return this.jsiiGet("internetConnectivityEstablished", software.amazon.awscdk.core.IDependable.class);
        }

        /**
         * The route table for this subnet.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.ec2.IRouteTable getRouteTable() {
            return this.jsiiGet("routeTable", software.amazon.awscdk.services.ec2.IRouteTable.class);
        }

        /**
         * The subnetId for this particular subnet.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getSubnetId() {
            return this.jsiiGet("subnetId", java.lang.String.class);
        }

        /**
         * The stack in which this resource is defined.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.Stack getStack() {
            return this.jsiiGet("stack", software.amazon.awscdk.core.Stack.class);
        }

        /**
         * The construct node in the tree.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.core.ConstructNode.class);
        }

        /**
         * Associate a Network ACL with this subnet.
         * 
         * @param id This parameter is required.
         * @param acl The Network ACL to associate. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public void associateNetworkAcl(final java.lang.String id, final software.amazon.awscdk.services.ec2.INetworkAcl acl) {
            this.jsiiCall("associateNetworkAcl", Void.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(acl, "acl is required") });
        }
    }
}

==> ec2-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/ISubnet.java <==
package software.amazon.awscdk.services.ec2;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:50.802Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.ISubnet")
@software.amazon.jsii.Jsii.Proxy(ISubnet.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ISubnet extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.core.IResource {

    /**
     * The Availability Zone the subnet is located in.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getAvailabilityZone();

    /**
     * Dependable that can be depended upon to force internet connectivity established on the VPC.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.core.IDependable getInternetConnectivityEstablished();

    /**
     * The route table for this subnet.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.ec2.IRouteTable getRouteTable();

    /**
     * The subnetId for this particular subnet.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getSubnetId();

    /**
     * Associate a Network ACL with this subnet.
     * 
     * @param id This parameter is required.
     * @param acl The Network ACL to associate. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    void associateNetworkAcl(final java.lang.String id, final software.amazon.awscdk.services.ec2.INetworkAcl acl);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.ISubnet {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * The Availability Zone the subnet is located in.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getAvailabilityZone() {
            return this.jsiiGet("availabilityZone", java.lang.String.class);
        }

        /**
         * Dependable that can be depended upon to force internet connectivity established on the VPC.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.IDependable getInternetConnectivityEstablished() {
            return this.jsiiGet("internetConnectivityEstablished", software.amazon.awscdk.core.IDependable.class);
        }

        /**
         * The route table for this subnet.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.ec2.IRouteTable getRouteTable() {
            return this.jsiiGet("routeTable", software.amazon.awscdk.services.ec2.IRouteTable.class);
        }

        /**
         * The subnetId for this particular subnet.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getSubnetId() {
            return this.jsiiGet("subnetId", java.lang.String.class);
        }

        /**
         * The stack in which this resource is defined.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.Stack getStack() {
            return this.jsiiGet("stack", software.amazon.awscdk.core.Stack.class);
        }

        /**
         * The construct node in the tree.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.core.ConstructNode.class);
        }

        /**
         * Associate a Network ACL with this subnet.
         * 
         * @param id This parameter is required.
         * @param acl The Network ACL to associate. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public void associateNetworkAcl(final java.lang.String id, final software.amazon.awscdk.services.ec2.INetworkAcl acl) {
            this.jsiiCall("associateNetworkAcl", Void.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(acl, "acl is required") });
        }
    }
}
